@@ -2,7 +2,8 @@ from airflow.models.baseoperator import BaseOperator
 from acceldata_sdk.torch_client import TorchClient
 from acceldata_airflow_sdk.initialiser import torch_credentials
 from acceldata_sdk.constants import FailureStrategy
-from acceldata_airflow_sdk.utils.constants import CONNECTION_ID, get_dag_run_pipeline_run_id
+from acceldata_airflow_sdk.utils.airflow_job_utils import CONNECTION_ID, get_dag_run_pipeline_run_id
+from acceldata_sdk.models.common_types import PolicyExecutionRequest
 
 import logging
 LOGGER = logging.getLogger("tasks")
@@ -23,7 +24,8 @@ class ExecutePolicyOperator(BaseOperator):
     """
 
     def __init__(self, *, policy_type, policy_id, sync, incremental=False,
-                 failure_strategy: FailureStrategy = FailureStrategy.DoNotFail, **kwargs):
+                 failure_strategy: FailureStrategy = FailureStrategy.DoNotFail,
+                 policy_execution_request: PolicyExecutionRequest = None, **kwargs):
         """
         :param policy_type: (PolicyType) Type of policy to be executed
         :param policy_id: (String) id of the policy to be executed
@@ -31,6 +33,10 @@ class ExecutePolicyOperator(BaseOperator):
         :param sync: (bool) optional Set it to True to execute policy in synchronous mode
         :param failure_strategy: (enum) optional Set it to decide if it should fail at error,
             fail at warning or never fail
+        :param policy_execution_request: (PolicyExecutionRequest) An optional parameter that allows you to provide
+        additional options for executing the policy. It is an instance of the PolicyExecutionRequest modules class,
+        which contains various properties that can be used to customize the policy execution, such as `executionType`,
+        `markerConfigs`, `ruleItemSelections`, and more.
 
         Example:
         from acceldata_sdk.constants import RuleExecutionStatus, FailureStrategy, PolicyType
@@ -41,6 +47,7 @@ class ExecutePolicyOperator(BaseOperator):
             policy_id=46,
             sync=True,
             failure_strategy=FailureStrategy.FailOnError,
+            policy_execution_request=policy_execution_request
             dag=dag
         )
 
@@ -57,7 +64,7 @@ class ExecutePolicyOperator(BaseOperator):
             execution_id = task_instance.xcom_pull(key=xcom_key)
             if execution_id is not None:
                 torch_client = TorchClient(**torch_credentials)
-                result = torch_client.get_polcy_execution_result(policy_type=PolicyType.DATA_QUALITY, execution_id=execution_id)
+                result = torch_client.get_policy_execution_result(policy_type=PolicyType.DATA_QUALITY, execution_id=execution_id)
         """
         super().__init__(**kwargs)
         self.policy_type = policy_type
@@ -65,6 +72,7 @@ class ExecutePolicyOperator(BaseOperator):
         self.incremental = incremental
         self.failure_strategy = failure_strategy
         self.sync = sync
+        self.policy_execution_request = policy_execution_request
 
     def execute(self, context):
         task_instance = context['ti']
@@ -77,7 +85,8 @@ class ExecutePolicyOperator(BaseOperator):
             sync=self.sync,
             incremental=self.incremental,
             failure_strategy=self.failure_strategy,
-            pipeline_run_id=pipeline_run_id
+            pipeline_run_id=pipeline_run_id,
+            policy_execution_request=self.policy_execution_request
         )
         if execution_return.id is not None:
             xcom_key = f'{self.policy_type.name}_{self.policy_id}_execution_id'
