@@ -1,8 +1,8 @@
 from datetime import datetime
 from airflow.models.baseoperator import BaseOperator
-from acceldata_sdk.events.generic_event import GenericEvent
-from acceldata_airflow_sdk.utils.constants import create_job_span
-
+from acceldata_airflow_sdk.utils.airflow_job_utils import create_job_span, log_job_details, get_task_instance, \
+    generate_job_uid, handle_span_success, create_context_job, is_span_not_found, create_new_span, \
+    handle_span_failure, create_context_job, generate_job_operator_uid, log_tries
 import logging
 
 LOGGER = logging.getLogger("airflow.task")
@@ -29,7 +29,9 @@ class JobOperator(BaseOperator):
     :param xcom_to_event_mapper_ids: list of xcom keys. Used to send xcom variables in span event job
     :param bounded_by_span: optional True if you want to create a span for the current task
     """
-    def __init__(self, *, operator: BaseOperator, inputs=[], outputs=[], job_uid: str=None, metadata=None, span_uid: str = None,
+
+    def __init__(self, *, operator: BaseOperator, inputs=[], outputs=[], job_uid: str = None, metadata=None,
+                 span_uid: str = None,
                  xcom_to_event_mapper_ids=None, bounded_by_span=True, **kwargs):
         """
         You need to add extra parameter mentioned below. Other parameters will be same as std airflow base operator's parameters
@@ -84,12 +86,11 @@ class JobOperator(BaseOperator):
         self.bounded_by_span = bounded_by_span
 
     def execute(self, context):
-        context_job = {'job': 'torch_job_operator', 'time': str(datetime.now()), 'uid': self.job_uid,
-                       'operator': str(self.operator)}
+        xcom_context_data = None
+        context_job = create_context_job("operator", self.job_uid, "operator", str(self.operator))
         task_instance = context['ti']
         if self.job_uid is None:
-            opame_six = '{:.6}'.format(type(self.operator).__name__)
-            self.job_uid = f'{self.operator.task_id}_{opame_six}'
+            self.job_uid = generate_job_operator_uid(type(self.operator).__name__, self.operator.task_id)
         self.span_uid, context, xcom_context_data = create_job_span(
             task_instance=task_instance,
             job_uid=self.job_uid,
@@ -103,6 +104,9 @@ class JobOperator(BaseOperator):
             kwargs=context
         )
         self.span_context = context.get('span_context_parent', None)
+        try_number = task_instance.try_number
+        max_retries = task_instance.task.retries
+        log_tries(try_number, max_retries)
         try:
             try:
                 self.operator.prepare_for_execution().execute(context)
@@ -121,17 +125,9 @@ class JobOperator(BaseOperator):
             exception = e.__dict__
             LOGGER.error(exception)
             if self.span_context is not None:
-                self.span_context.send_event(
-                    GenericEvent(context_data={'status': 'error', 'error_data': str(e), 'time': str(datetime.now()),
-                                               'exception_type': str(type(e).__name__)},
-                                 event_uid=f'{self.span_uid}.error.event'))
-                self.span_context.failed(
-                    context_data=xcom_context_data)
-                raise e
+                handle_span_failure(e, self.span_context, self.span_uid, try_number, xcom_context_data, max_retries)
         else:
-            LOGGER.info("Send span end success event")
-            if self.span_context is not None:
-                self.span_context.end(context_data=xcom_context_data)
+            handle_span_success(self.span_context, self.span_uid, try_number, xcom_context_data)
 
     def set_downstream(self, task_or_task_list) -> None:
         super().set_downstream(task_or_task_list)
