@@ -1,30 +1,26 @@
 from datetime import datetime
 from airflow.models.baseoperator import BaseOperator
 from urllib import parse
-
 from acceldata_sdk.events.generic_event import GenericEvent
-from acceldata_sdk.models.pipeline import CreatePipeline, PipelineMetadata
+from acceldata_sdk.models.pipeline import CreatePipeline, PipelineMetadata, PipelineSourceType
 from acceldata_sdk.torch_client import TorchClient
+from acceldata_sdk.api_version_utils import APIVersionUtils
 from acceldata_airflow_sdk.initialiser import torch_credentials
 from acceldata_airflow_sdk.utils.torch_client import TorchDAGClient
-from acceldata_airflow_sdk.utils.constants import PIPELINE_UID_XCOM, is_pipeline_run_ended, CONNECTION_ID
+from acceldata_airflow_sdk.utils.airflow_job_utils import PIPELINE_UID_XCOM, is_pipeline_run_ended, CONNECTION_ID
+from semantic_version import Version, SimpleSpec
+import logging
 
 
-def check_int(input_str):
-    try:
-        int(input_str)
-        return True
-    except ValueError:
-        return False
-
+LOGGER = logging.getLogger("airflow.task")
 
 def check_if_pipeline_exists(pipeline_uid: str, client):
     try:
         pipeline = client.get_pipeline(pipeline_uid=pipeline_uid)
-        print('check_if_pipeline_exists:: pipeline: ', pipeline)
+        LOGGER.info('check_if_pipeline_exists:: pipeline:  %s ', pipeline)
         return True
     except Exception as e:
-        print('check_if_pipeline_exists:: pipeline: False -> ERROR :', str(e))
+        LOGGER.warn('check_if_pipeline_exists:: pipeline: False -> ERROR : %s ', str(e))
         return False
 
 
@@ -75,19 +71,20 @@ class TorchInitializer(BaseOperator):
             pipeline_name_ = self.pipeline_uid
             if self.pipeline_name is not None:
                 pipeline_name_ = self.pipeline_name
-            print('Creating new pipeline with passed uid.')
-            pipeline = CreatePipeline(
-                uid=self.pipeline_uid,
-                name=pipeline_name_,
-                description=f'The pipeline {pipeline_name_} has been created from acceldata-airflow-sdk',
-                meta=self.meta,
-                context={'pipeline_uid': self.pipeline_uid, 'pipeline_name': pipeline_name_}
-            )
+            LOGGER.info('Creating new pipeline with passed uid :: %s',self.pipeline_uid)
             torch_client = TorchClient(**torch_credentials(self.connection_id))
+            pipeline = CreatePipeline(
+                    uid=self.pipeline_uid,
+                    name=pipeline_name_,
+                    description=f'The pipeline {pipeline_name_} has been created from acceldata-airflow-sdk',
+                    meta=self.meta,
+                    context={'pipeline_uid': self.pipeline_uid, 'pipeline_name': pipeline_name_},
+                    sourceType=PipelineSourceType.AIRFLOW
+            )
             pipeline_res = torch_client.create_pipeline(pipeline=pipeline)
-            print('pipeline id :: ', pipeline_res.id)
+            LOGGER.info('pipeline id :: %s', pipeline_res.id)
             if self.continuation_id is not None:
-                print(f'Creating new pipeline run with passed continuation_id : {self.continuation_id}.')
+                LOGGER.info(f'Creating new pipeline run with passed continuation_id :: %s {self.continuation_id}.')
                 pipeline_run = pipeline_res.create_pipeline_run(continuation_id=self.continuation_id)
             else:
                 pipeline_run = pipeline_res.create_pipeline_run()
@@ -100,20 +97,20 @@ class TorchInitializer(BaseOperator):
         else:
             client = TorchDAGClient(self.connection_id)
             if self.continuation_id is not None:
-                print('Using precreated pipeline with continuation_id :: ', self.continuation_id)
+                LOGGER.info('Using precreated pipeline with continuation_id :: %s ', self.continuation_id)
                 pipeline = client.get_pipeline(self.pipeline_uid)
                 pipeline_run = client.get_pipeline_run(continuation_id=self.continuation_id, pipeline_id=pipeline.id)
                 if is_pipeline_run_ended(pipeline_run):
                     raise Exception("Please provide continuation_id of active pipeline run")
             else:
-                print('Using latest pipeline run.')
+                LOGGER.info('Using latest pipeline run.')
                 pipeline_run = client.get_latest_pipeline_run(self.pipeline_uid)
                 if is_pipeline_run_ended(pipeline_run):
                     raise Exception("Latest pipeline run is in terminal state. Please make sure latest pipeline run is not completed")
             parent_span_context = client.get_root_span(pipeline_uid=self.pipeline_uid,
                                                        pipeline_run_id=pipeline_run.id)
             task_instance.xcom_push(key=f'{task_instance.dag_id}_pipeline_run_id', value=pipeline_run.id)
-            print('Using precreated pipeline with pipeline uid :: ', self.pipeline_uid)
+            LOGGER.info('Using precreated pipeline with pipeline uid :: %s ', self.pipeline_uid)
         try:
             log_url = list({context.get('task_instance').log_url})
             list_ = list(log_url)
